@@ -1,6 +1,6 @@
 -- todo: come up with an auto-texlive identification (texmf-dist)
 
-local hiddentexlivepath = ".texlive2024"
+local hiddentexlivepath = ".texlive2025"
 
 return {
 
@@ -79,8 +79,16 @@ return {
             TEXMFSYSCONFIG  = "/usr/pkg/etc/texmf",
 
             -- The texmf-local path is only used for (maybe) some additional configuration file.
-
-            TEXMFLOCAL      = "selfautoparent:texmf-local",
+	    -- Changed texmf-local to use ../ per Bruno Voisin,
+	    --   https://tug.org/pipermail/tex-live/2024-March/050300.html
+	    -- Needed: mtxrun --generate; mtxrun --script fonts --reload
+	    -- Then to test, e.g.:
+	    --   mtxrun --resolve-path TEXMFLOCAL
+	    --   mtxrun --find-file LucidaBrightOT.otf
+	    -- More info:
+	    --   https://wiki.contextgarden.net/Use_the_fonts_you_want
+	    --   https://wiki.contextgarden.net/Mtxrun#base and #fontsa
+            TEXMFLOCAL      = "selfautoparent:../texmf-local",
             TEXMFFONTS      = "selfautoparent:texmf-fonts",
             TEXMFPROJECT    = "selfautoparent:texmf-project",
 
